/************************************************************************
              WinControl Command Declarations (General)

              This is a part outof WinControl SDK package.
              Version History:
              v1.00 - 1999/09/03*
              v1.30 - 2000/01/26 - Major Update, first public release

              Last modifyed 2000/01/26
              (c)1999-2000 HALAN Innovations, all rights reserved
              Author: Daniel Halan (daniel@wincontrol.com)

**************************************************************************/

#include <kmdstd.h>

wMainValues wincon;


wVisible **CreateVis(WORD iVisCount, wVisible *pvArr[])
{
	wVisible **Result = (wVisible**)NewArr(iVisCount);
	wVisible **VisArr = Result;
	for (int x = 0; x < iVisCount;x++)
	{
		*VisArr = pvArr[x];
		VisArr++;
	};
	return Result;
};

void DispVis(WORD iCount, void *P)
{
	wVisible **vArr = (wVisible**)P;
	for (int x = 0; x < iCount;x++)
	{
		delete *vArr;
		vArr++;
	};
	if (P != NULL) { DispArr(P); };
};

wParamValue* CreateParamValue(wParamType pType, void *pData, long pVal = 0)
{
	wParamValue *Prm = new wParamValue;
	Prm->vType	= pType;
	Prm->Data		= pData;
	Prm->Value	= pVal;
	return Prm;
};


wParamValue* CreateEdit(char *pcText,char *pcValue, wEditExtras eExtra, char *eExtraExt,
WORD iMax, long hContx, WORD VisCount, wVisible *pvArr[], byte iPropWidth, 
byte iPropLeft, byte iTopPos, wOnChangeCB ocCB)
{
	wEdit *nEdit	= new wEdit;
	nEdit->Text		= pcText;
	nEdit->Value	= pcValue;
	nEdit->Extras	= eExtra;
	nEdit->ExtraExt	= eExtraExt;
	nEdit->Max		= iMax;
	nEdit->HelpContext	= hContx;
	nEdit->VisCount		= VisCount;
	nEdit->Visible		= CreateVis(VisCount,pvArr);
	nEdit->PropWidth	= iPropWidth;
	nEdit->PropLeft		= iPropLeft;
	nEdit->TopPos		= iTopPos;
	nEdit->DoOnChange = ocCB;
	return CreateParamValue(ptEdit,nEdit);
};

wParamValue* CreateIntEdit(char *pcText, long iValue, long iMax, long iMin, long hContx,
WORD VisCount, wVisible *pvArr[], byte iPropWidth, byte iPropLeft, byte iTopPos, 
 wOnChangeCB ocCB)
{
	wIntEdit *nEdit = new wIntEdit;
	nEdit->Text = pcText;
	nEdit->Value = iValue;
	nEdit->Max = iMax;
	nEdit->Min = iMin;
	nEdit->HelpContext	= hContx;
	nEdit->VisCount		= VisCount;
	nEdit->Visible		= CreateVis(VisCount,pvArr);
	nEdit->PropWidth	= iPropWidth;
	nEdit->PropLeft		= iPropLeft;
	nEdit->TopPos		= iTopPos;
	nEdit->DoOnChange = ocCB;
  return CreateParamValue(ptIntEdit,nEdit);
};

wParamValue* CreateComboBox(char *pcText, WORD iCount, char *pcItems[],
long iItemIndex, long hContx, WORD VisCount, wVisible *pvArr[], byte iPropWidth, 
byte iPropLeft, byte iTopPos, wOnChangeCB ocCB)
{
	wComboBox *nCombo = new wComboBox;
	nCombo->Text = pcText;
	nCombo->ItemCount = iCount;
	nCombo->Items = (char**)NewArr(iCount);
	for (long x = 0; x < iCount; x++) { nCombo->Items[x] = pcItems[x]; };
	nCombo->ItemIndex = iItemIndex;
	nCombo->HelpContext = hContx;
	nCombo->VisCount	= VisCount;
	nCombo->Visible		= CreateVis(VisCount,pvArr);
	nCombo->PropWidth = iPropWidth;
	nCombo->PropLeft = iPropLeft;
	nCombo->TopPos = iTopPos;
	nCombo->DoOnChange = ocCB;

  return CreateParamValue(ptCombo,nCombo);
};

wParamValue *CreateRadioGroup(char *pcText, WORD iCount,char *pcItems[], //: array of PChar;
long iItemIndex, long hContx, WORD VisCount, wVisible *pvArr[], byte iPropWidth, byte iPropLeft, 
byte iTopPos, WORD iHeight, wOnChangeCB ocCB)
{
	wRadioGroup *nRadio = new wRadioGroup;
	nRadio->Text = pcText;
	nRadio->ItemCount = iCount;
	nRadio->Items = (char**)NewArr(iCount);
	for (long x = 0; x < iCount; x++) { nRadio->Items[x] = pcItems[x]; };
	nRadio->ItemIndex = iItemIndex;
	nRadio->HelpContext = hContx;
	nRadio->VisCount	= VisCount;
	nRadio->Visible		= CreateVis(VisCount,pvArr);
	nRadio->PropWidth = iPropWidth; // %
	nRadio->PropLeft = iPropLeft;
	nRadio->TopPos = iTopPos;
	nRadio->Height = iHeight;
	nRadio->DoOnChange = ocCB;
	return CreateParamValue(ptRadioGroup,nRadio);
};

wParamValue* CreateCheckBox(char *pcText, BOOL bChecked, long hContx,
WORD VisCount, wVisible *pvArr[], byte iPropWidth, byte iPropLeft, byte iTopPos, wOnChangeCB ocCB)
{
	wCheckBox *nCheck = new wCheckBox;
	nCheck->Text = pcText;
	nCheck->Checked = bChecked;
	nCheck->HelpContext = hContx;
	nCheck->VisCount	= VisCount;
	nCheck->Visible		= CreateVis(VisCount,pvArr);
	nCheck->PropWidth = iPropWidth;
	nCheck->PropLeft = iPropLeft;
	nCheck->TopPos = iTopPos;
	nCheck->DoOnChange = ocCB;
	return CreateParamValue(ptCheckBox,nCheck);
};


wParam* NewParams(char *pcName, WORD iCount, WORD iHeight, WORD iWidth, HICON iIcon)
{
	wParam *Prm = new wParam;
	Prm->Name = pcName;
	Prm->hIcon = (DWORD)iIcon;
	Prm->Width = iWidth;
	Prm->Height = iHeight;
	Prm->ValueCount = iCount;
	Prm->Values = (void**)NewArr(iCount);
	return Prm;
};

wError FreeParams(wParam *Params)
{
	wParamValue *PrmVal = NULL;
	for (long x = 0; x < Params->ValueCount; x++)
		{
		PrmVal = ((wParamValue*)Params->Values[x]);
        DispVis( ((wVisObj*)PrmVal->Data)->VisCount,((wVisObj*)PrmVal->Data)->Visible);
		switch ( PrmVal->vType)
		{
          case ptCombo:
            {
              DispArr(((wComboBox*)PrmVal->Data)->Items);
              ((wComboBox*)PrmVal->Data)->Text = NULL;
              delete ((wComboBox*)PrmVal->Data);
			  break;
            };
          case ptRadioGroup:
            {
              DispArr(((wRadioGroup*)PrmVal->Data)->Items);
              ((wRadioGroup*)PrmVal->Data)->Text = NULL;
              delete ((wRadioGroup*)PrmVal->Data);
			  break;
            };
          case ptEdit:
			{
              FreePChar(((char*)PrmVal->Value));
              delete ((wEdit*)PrmVal->Data);
			  break;
			};			
		  case ptIntEdit:
			{
              delete ((wIntEdit*)PrmVal->Data);
			  break;
			};
		  case ptCheckBox:
			{
              delete ((wCheckBox*)PrmVal->Data);
			  break;
			};
		  case ptPageControl:
			{
              delete ((wPageControl*)PrmVal->Data);
			  break;
			};

		  default: delete PrmVal->Data;
		};
          delete PrmVal;
          Params->Values[x] = NULL;
		};
	DispArr(Params->Values);
	delete Params;
	return ERR_NOPROBLEM;
};
